pub enum Selected {
Waiting,
Aborted,
Disconnected,
Operation(Operation),
}🔬This is a nightly-only experimental API. (
mpmc_channel #126840)Expand description
Current state of a blocking operation.
Variants
Waiting
🔬This is a nightly-only experimental API. (
mpmc_channel #126840)Still waiting for an operation.
Aborted
🔬This is a nightly-only experimental API. (
mpmc_channel #126840)The attempt to block the current thread has been aborted.
Disconnected
🔬This is a nightly-only experimental API. (
mpmc_channel #126840)An operation became ready because a channel is disconnected.
Operation(Operation)
🔬This is a nightly-only experimental API. (
mpmc_channel #126840)An operation became ready because a message can be sent or received.